==> nextcloud-20.0.8p0.tgz: nextcloud/apps/weather_status/l10n/ja.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "アドレスが見つかりません",
    "No result." : "結果なし",
    "Malformed JSON data." : "JSONデータの形式に誤りがあります",
    "Error" : "エラー",
    "Weather status" : "現在の天気",
    "Weather status in your dashboard" : "ダッシュボードにおける天気の表示",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "天気ウィジットはダッシュボードアプリに統合されています。ユーザの現在地は自動または手動で設定でき、その地点の6時間予報が表示されます。このウィジットはカレンダーアプリなど他の場所にも統合させることができます。",
    "Detect location" : "地域を検出",
    "Set custom address" : "地域を入力",
    "Favorites" : "お気に入り",
    "{temperature} {unit} Clear sky at {time}" : "{time} の天気は快晴、気温は {temperature} {unit}",
    "{temperature} {unit} Cloudy at {time}" : "{time} の天気は曇り、気温は {temperature} {unit}",
    "{temperature} {unit} Fair day at {time}" : "{time} の天気は晴れ、気温は {temperature} {unit}",
    "{temperature} {unit} Fair night at {time}" : "{time} の天気は晴れ、気温は {temperature} {unit}",
    "{temperature} {unit} Partly cloudy at {time}" : "{time} の天気は一部曇り、気温は {temperature} {unit}",
    "{temperature} {unit} Foggy at {time}" : "{time} の天気は霧、気温は {temperature} {unit}",
    "{temperature} {unit} Light rain at {time}" : "{time} の天気は小雨、気温は {temperature} {unit}",
    "{temperature} {unit} Rain at {time}" : "{time} の天気は雨、気温は {temperature} {unit}",
    "{temperature} {unit} Heavy rain at {time}" : "{time} の天気は大雨、気温は {temperature} {unit}",
    "{temperature} {unit} Rain showers at {time}" : "{time} の天気はにわか雨、気温は {temperature} {unit}",
    "{temperature} {unit} Light rain showers at {time}" : "{time} の天気は弱いにわか雨、気温は {temperature} {unit}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{time} の天気は強いにわか雨、気温は {temperature} {unit}",
    "More weather for {adr}" : "{adr} の詳しい天気",
    "Loading weather" : "天気を読み込み中",
    "Set location for weather" : "天気の地域設定",
    "Remove from favorites" : "お気に入りから削除",
    "Add as favorite" : "お気に入りに追加",
    "You are not logged in." : "ログインしていません",
    "There was an error getting the weather status information." : "天気情報取得時にエラーが発生しました",
    "No weather information found" : "天気情報が見つかりません",
    "Location not found" : "地域が見つかりません",
    "There was an error setting the location address." : "住所設定時にエラーが発生しました",
    "There was an error setting the location." : "地域設定時にエラーが発生しました",
    "There was an error saving the mode." : "モードの保存時にエラーが発生しました",
    "There was an error using personal address." : "個人の住所使用時にエラーが発生しました",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "天気ウィジットはダッシュボードアプリに統合されています。ユーザの現在地は自動または手動で設定でき、その地点の6時間予報が表示されます。このウィジットはカレンダーアプリなど他の場所にも統合させることができます。"
},
"nplurals=1; plural=0;");

==> nextcloud-21.0.3.tgz: nextcloud/apps/weather_status/l10n/ja.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "アドレスが見つかりません",
    "No result." : "結果なし",
    "Malformed JSON data." : "JSONデータの形式に誤りがあります",
    "Error" : "エラー",
    "Weather status" : "現在の天気",
    "Weather status in your dashboard" : "ダッシュボードにおける天気の表示",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "天気ウィジットはダッシュボードアプリに統合されています。ユーザーの現在地は自動または手動で設定でき、その地点の6時間予報が表示されます。このウィジットはカレンダーアプリなど他の場所にも統合させることができます。",
    "Detect location" : "地域を検出",
    "Set custom address" : "地域を入力",
    "Favorites" : "お気に入り",
    "{temperature} {unit} Clear sky at {time}" : "{time} の天気は快晴、気温は {temperature} {unit}",
    "{temperature} {unit} Cloudy at {time}" : "{time} の天気は曇り、気温は {temperature} {unit}",
    "{temperature} {unit} Fair day at {time}" : "{time} の天気は晴れ、気温は {temperature} {unit}",
    "{temperature} {unit} Fair night at {time}" : "{time} の天気は晴れ、気温は {temperature} {unit}",
    "{temperature} {unit} Partly cloudy at {time}" : "{time} の天気は一部曇り、気温は {temperature} {unit}",
    "{temperature} {unit} Foggy at {time}" : "{time} の天気は霧、気温は {temperature} {unit}",
    "{temperature} {unit} Light rain at {time}" : "{time} の天気は小雨、気温は {temperature} {unit}",
    "{temperature} {unit} Rain at {time}" : "{time} の天気は雨、気温は {temperature} {unit}",
    "{temperature} {unit} Heavy rain at {time}" : "{time} の天気は大雨、気温は {temperature} {unit}",
    "{temperature} {unit} Rain showers at {time}" : "{time} の天気はにわか雨、気温は {temperature} {unit}",
    "{temperature} {unit} Light rain showers at {time}" : "{time} の天気は弱いにわか雨、気温は {temperature} {unit}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{time} の天気は強いにわか雨、気温は {temperature} {unit}",
    "More weather for {adr}" : "{adr} の詳しい天気",
    "Loading weather" : "天気を読み込み中",
    "Set location for weather" : "天気の地域設定",
    "Remove from favorites" : "お気に入りから削除",
    "Add as favorite" : "お気に入りに追加",
    "You are not logged in." : "ログインしていません",
    "There was an error getting the weather status information." : "天気情報取得時にエラーが発生しました",
    "No weather information found" : "天気情報が見つかりません",
    "Location not found" : "地域が見つかりません",
    "There was an error setting the location address." : "住所設定時にエラーが発生しました",
    "There was an error setting the location." : "地域設定時にエラーが発生しました",
    "There was an error saving the mode." : "モードの保存時にエラーが発生しました",
    "There was an error using personal address." : "個人の住所使用時にエラーが発生しました",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "天気ウィジットはダッシュボードアプリに統合されています。ユーザーの現在地は自動または手動で設定でき、その地点の6時間予報が表示されます。このウィジットはカレンダーアプリなど他の場所にも統合させることができます。"
},
"nplurals=1; plural=0;");
